@@ -18,6 +18,7 @@
 #' binaries in Rtools may conflict with existing binaries elsewhere on the PATH it
 #' is better practice to use `with_build_tools()` as needed.
 #' @inheritParams has_rtools
+#' @param quiet if `TRUE` suppresses output from this function.
 #' @export
 #' @seealso has_rtools
 #' @examples
@@ -25,7 +26,9 @@
 #' check_build_tools()
 has_build_tools <- function(debug = FALSE) {
   check <- getOption("buildtools.check", NULL)
-  if (!is.null(check)) {
+  if(is_windows() && is_R4() && has_rtools(debug = debug)){
+    TRUE
+  } else if (!is.null(check)) {
     check("Building R package from source")
   } else if (is_windows()) {
     has_rtools(debug = debug)
@@ -36,12 +39,12 @@ has_build_tools <- function(debug = FALSE) {
 
 #' @export
 #' @rdname has_build_tools
-check_build_tools <- function(debug = FALSE) {
+check_build_tools <- function(debug = FALSE, quiet = FALSE) {
   if (!has_build_tools(debug = debug)) {
     stop(
       "Could not find tools necessary to compile a package\n",
       "Call `pkgbuild::check_build_tools(debug = TRUE)` to diagnose the problem.", call. = FALSE)
-  } else {
+  } else if (!isTRUE(quiet)) {
     message("Your system is ready to build packages!")
   }
 
@@ -57,7 +60,7 @@ check_build_tools <- function(debug = FALSE) {
 #'   them.
 with_build_tools <- function(code, debug = FALSE, required = TRUE) {
   if (required)
-    check_build_tools(debug = debug)
+    check_build_tools(debug = debug, quiet = TRUE)
 
   if (has_rtools()) {
     withr::with_path(rtools_path(), code)
@@ -71,7 +74,7 @@ with_build_tools <- function(code, debug = FALSE, required = TRUE) {
 #' @export
 local_build_tools <- function(debug = FALSE, required = TRUE, .local_envir = parent.frame()) {
   if (required)
-    check_build_tools(debug = debug)
+    check_build_tools(debug = debug, quiet = TRUE)
 
   if (has_rtools()) {
     withr::local_path(rtools_path(), .local_envir = .local_envir)
